Class: Ecfr::OfrProfileService::Base

Inherits:
Base
  • Object
show all
Defined in:
lib/ecfr/ofr_profile_service/base.rb

Direct Known Subclasses

Status

Class Method Summary collapse

Class Method Details

.base_urlObject



6
7
8
# File 'lib/ecfr/ofr_profile_service/base.rb', line 6

def self.base_url
  Ecfr.config.ofr_profile_service_url || Ecfr.config.ofr_profile_service_base_url
end

.service_nameObject



17
18
19
# File 'lib/ecfr/ofr_profile_service/base.rb', line 17

def self.service_name
  "OFR Profile"
end

.service_pathObject

path is relative because we expect the ofr profile api to be mounted at a subpath and an absolute url here will cause the path in the config to be lost



13
14
15
# File 'lib/ecfr/ofr_profile_service/base.rb', line 13

def self.service_path
  Ecfr.config.ofr_profile_service_path || "api/profile"
end