Class: Ecfr::VersionerService::Authority
- Defined in:
- lib/ecfr/versioner_service/authority.rb
Overview
Authority entries represent individual references in the Parallel Table of Authorities.
Constant Summary collapse
- AUTHORITIES_PATH =
"v1/authorities"
Instance Attribute Summary collapse
-
#categories ⇒ String
readonly
reference categories included in this response.
-
#components ⇒ String
readonly
authority citation components.
-
#date ⇒ Date
readonly
authority citation date.
-
#kind ⇒ String
readonly
authority reference kind.
-
#references ⇒ String
readonly
CFR titles, parts, and hierarchies that cite this authority.
Class Method Summary collapse
-
.all(options = {}) ⇒ Authority
Retrieves the Parallel Table of Authorities data.
Methods inherited from Base
base_url, service_name, service_path
Instance Attribute Details
#categories ⇒ String (readonly)
reference categories included in this response
27 28 |
# File 'lib/ecfr/versioner_service/authority.rb', line 27 :categories, desc: "reference categories included in this response" |
#components ⇒ String (readonly)
authority citation components
13 14 |
# File 'lib/ecfr/versioner_service/authority.rb', line 13 attribute :components, desc: "authority citation components" |
#date ⇒ Date (readonly)
authority citation date
16 17 18 |
# File 'lib/ecfr/versioner_service/authority.rb', line 16 attribute :date, type: :date, desc: "authority citation date" |
#kind ⇒ String (readonly)
authority reference kind
10 11 |
# File 'lib/ecfr/versioner_service/authority.rb', line 10 attribute :kind, desc: "authority reference kind" |
#references ⇒ String (readonly)
CFR titles, parts, and hierarchies that cite this authority
20 21 |
# File 'lib/ecfr/versioner_service/authority.rb', line 20 attribute :references, desc: "CFR titles, parts, and hierarchies that cite this authority" |
Class Method Details
.all(options = {}) ⇒ Authority
Retrieves the Parallel Table of Authorities data.
38 39 40 41 42 43 44 45 |
# File 'lib/ecfr/versioner_service/authority.rb', line 38 def self.all( = {}) year = .fetch(:year, "current") perform( :get, "#{AUTHORITIES_PATH}/#{year}" ) end |